[Pkg-javascript-commits] [d3-tip.js] 111/277: complete rename of text to html

bhuvan krishna bhuvan-guest at moszumanska.debian.org
Thu Dec 8 06:57:21 UTC 2016


This is an automated email from the git hooks/post-receive script.

bhuvan-guest pushed a commit to branch master
in repository d3-tip.js.

commit b59d81b5c456dc6d16470ed13f56884d50cbb2ee
Author: Justin Palmer <justin at github.com>
Date:   Sun Apr 21 15:25:11 2013 -0700

    complete rename of text to html
---
 src/d3.tip.js | 16 ++++++++--------
 1 file changed, 8 insertions(+), 8 deletions(-)

diff --git a/src/d3.tip.js b/src/d3.tip.js
index c24429b..9bc1c9a 100644
--- a/src/d3.tip.js
+++ b/src/d3.tip.js
@@ -4,7 +4,7 @@
 d3.tip = function() {
   var direction = d3_svg_direction,
       offset    = d3_svg_offset,
-      text      = d3_svg_text,
+      html      = d3_svg_html,
       node      = init_node(),
       svg       = null,
       point     = null;
@@ -19,7 +19,7 @@ d3.tip = function() {
   //
   // Returns a tip
   tip.show = function() {
-    var content = text.apply(this, arguments),
+    var content = html.apply(this, arguments),
         poffset = offset.apply(this, arguments),
         dir     = direction.apply(this, arguments),
         dirs    = direction_callbacks.keys(),
@@ -42,7 +42,7 @@ d3.tip = function() {
   // Returns a tip
   tip.hide = function() {
     node.style.display = 'none'
-    node.innerText = ''
+    node.innerHTML = ''
 
     return tip
   }
@@ -101,21 +101,21 @@ d3.tip = function() {
     return tip;
   };
 
   // Public: sets or gets the text value of the tooltip
   //
   // v - String value of the tip
   //
   // Returns text value or tip
   tip.html = function(v) {
-    if (!arguments.length) return text;
-    text = v == null ? v : d3.functor(v)
+    if (!arguments.length) return html;
+    html = v == null ? v : d3.functor(v)
 
     return tip
   };
 
   function d3_svg_direction() { return 'n' }
   function d3_svg_offset() { return [0, 0] }
-  function d3_svg_text() { return ' ' }
+  function d3_svg_html() { return ' ' }
 
   var direction_callbacks = d3.map({
     n: direction_n,
@@ -101,21 +101,21 @@ d3.tip = function() {
   };
 
-  // Public: sets or gets the text value of the tooltip
+  // Public: sets or gets the html value of the tooltip
   //
   // v - String value of the tip
@@ -101,21 +101,21 @@ d3.tip = function() {
   // v - String value of the tip
   //
-  // Returns text value or tip
+  // Returns html value or tip
   tip.html = function(v) {

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-javascript/d3-tip.js.git



More information about the Pkg-javascript-commits mailing list